import { FernConfigurationSchema } from "@fern-api/yaml-schema";
import { ZodError } from "zod";
import { RelativeFilePath } from "./RelativeFilePath";
import { Workspace } from "./Workspace";
export declare namespace WorkspaceParser {
    type Result = SuccessfulResult | FailedResult;
    interface SuccessfulResult {
        didSucceed: true;
        workspace: Workspace;
    }
    interface FailedResult {
        didSucceed: false;
        failures: Record<RelativeFilePath, Failure>;
    }
    type Failure = FileReadFilure | FileParseFailure | StructureValidationFailure;
    interface FileReadFilure {
        type: WorkspaceParserFailureType.FILE_READ;
        error: unknown;
    }
    interface FileParseFailure {
        type: WorkspaceParserFailureType.FILE_PARSE;
        error: unknown;
    }
    interface StructureValidationFailure {
        type: WorkspaceParserFailureType.STRUCTURE_VALIDATION;
        error: ZodError<FernConfigurationSchema>;
    }
}
export declare enum WorkspaceParserFailureType {
    FILE_READ = "FILE_READ",
    FILE_PARSE = "FILE_PARSE",
    STRUCTURE_VALIDATION = "STRUCTURE_VALIDATION"
}
